Documentation
¶
Overview ¶
Package cablefyi provides a Go client for the CableFYI API (cablefyi.com).
CableFYI — zero dependencies, no authentication required.
Usage:
client := cablefyi.NewClient()
result, err := client.Search("query")
Index ¶
- Constants
- type Client
- func (c *Client) Benchmark(slug string) (map[string]interface{}, error)
- func (c *Client) Benchmarks() (map[string]interface{}, error)
- func (c *Client) Cable(slug string) (map[string]interface{}, error)
- func (c *Client) Cables() (map[string]interface{}, error)
- func (c *Client) Compatibility() (map[string]interface{}, error)
- func (c *Client) Connector(slug string) (map[string]interface{}, error)
- func (c *Client) Connectors() (map[string]interface{}, error)
- func (c *Client) Device(slug string) (map[string]interface{}, error)
- func (c *Client) Devices() (map[string]interface{}, error)
- func (c *Client) Faq(slug string) (map[string]interface{}, error)
- func (c *Client) Faqs() (map[string]interface{}, error)
- func (c *Client) Guide(slug string) (map[string]interface{}, error)
- func (c *Client) GuideSeries() (map[string]interface{}, error)
- func (c *Client) GuideSery(slug string) (map[string]interface{}, error)
- func (c *Client) Guides() (map[string]interface{}, error)
- func (c *Client) Search(query string) (map[string]interface{}, error)
- func (c *Client) SetupGuide(slug string) (map[string]interface{}, error)
- func (c *Client) SetupGuides() (map[string]interface{}, error)
- func (c *Client) Standard(slug string) (map[string]interface{}, error)
- func (c *Client) Standards() (map[string]interface{}, error)
- func (c *Client) Term(slug string) (map[string]interface{}, error)
- func (c *Client) Terms() (map[string]interface{}, error)
Constants ¶
const DefaultBaseURL = "https://cablefyi.com"
DefaultBaseURL is the default API base URL.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
Client is a CableFYI API client.
func (*Client) Benchmarks ¶
Benchmarks returns a list of benchmarks.
func (*Client) Compatibility ¶
Compatibility returns a list of compatibility.
func (*Client) Connectors ¶
Connectors returns a list of connectors.
func (*Client) GuideSeries ¶
GuideSeries returns a list of guide series.
func (*Client) SetupGuide ¶
SetupGuide returns details for a setup guide by slug.
func (*Client) SetupGuides ¶
SetupGuides returns a list of setup guides.
Click to show internal directories.
Click to hide internal directories.